package main

import (
	"flag"
	"log"
	"os"
	"os/signal"
	"path"
	"syscall"
)

func init() {
	log.SetOutput(os.Stdout)
}

var verbose bool

func main() {
	configFile := flag.String("config", "", "path to configuration file")
	flag.BoolVar(&verbose, "verbose", false, "print request and response information")
	flag.Parse()

	if *configFile == "" {
		homedir, err := os.UserHomeDir()
		if err == nil && homedir != "" {
			*configFile = path.Join(homedir, ".config", "twins", "config.yaml")
		}
	}

	sig := make(chan os.Signal, 1)
	signal.Notify(sig, syscall.SIGHUP)
	go func() {
		for {
			<-sig
			err := readconfig(*configFile)
			if err != nil {
				log.Fatalf("failed to reload configuration file at %s: %v", *configFile, err)
			}
			log.Println("configuration reloaded successfully")
		}
	}()

	err := readconfig(*configFile)
	if err != nil {
		log.Fatalf("failed to read configuration file at %s: %v\nSee CONFIGURATION.md for information on configuring twins", *configFile, err)
	}

	log.Printf("twins running on %s:%d", config.hostname, config.port)

	listen(config.Listen)
}
